==> rnews-0.80.tar.gz: rnews-0.80/inc/output.php <==
<?php

require_once('rss.php');

// -------------------------------------------------------------------------------
function outputHeader ($user = NULL, $t = NULL, $status = NULL, $onload = NULL, $meta = NULL) {

  $title = defined('RNEWS_TITLE') ? RNEWS_TITLE : 'Rnews RSS Feeds';
  if (!empty($t)) { $title .= ": $t"; }

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<?php if ($meta) echo $meta ?>
    <link rel="stylesheet" href="rnews-side.css" type="text/css" />
    <script type="text/javascript" src="ajax.js"></script>
    <title><?php echo $title ?></title>
  </head>
  <body<?php if ($onload) echo " onload=\"$onload\"" ?>>
  <div id="container">
  <div id="header">
<?php
  if ($user != NULL)
    echo '<h1><a href="index.php?category='. $user->default_cat .'">Rnews RSS Feeds</a></h1>';
  else
    echo '<h1>Rnews RSS Feeds</h1>';
?>
    <?php outputUserActions($user) ?>
    <div id="status"><?php echo $status ? $status : '&nbsp;' ?></div>
  </div>
<?php

}

// -------------------------------------------------------------------------------
function outputUserActions(&$user) {
  echo '<div class="actions">';
  if ($user !== NULL && !$user->restricted) {
    echo htmlspecialchars($user->name) .': ';
    echo '<a href="prefs.php">Preferences</a>&nbsp;|&nbsp; ';
    echo '<a href="auth.php?logout=1">Log Out</a>';
  } else {
    echo '<a href="auth.php">Log In</a>';
  }
  echo '</div>';
}

// -------------------------------------------------------------------------------
// This provides category links in the header
//
function outputNavigation (&$db, &$user, $selCatId = 0) {

  echo '<div id="navigation"><ul>';
  echo '<li><a href="index.php"><em>All Sources</em></a></li>';

	foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
		echo '<li'. (($selCatId && ($selCatId == $cat->id)) ? ' class="selected"' : '')
			.'><a href="index.php?category='. $cat->id .'">'. htmlspecialchars($cat->name) .'</a></li>';
	}

  echo '</ul></div>' . "\n";
}

// -------------------------------------------------------------------------------
function outputCatHead (&$user, &$cat, $args) {
  echo "\n<div class=\"category\">\n";
  echo '<div class="categoryHead clearfix">';
  echo '<h2><a href="' . $_SERVER['PHP_SELF'] . "?category=$cat->id\">". htmlspecialchars($cat->name) ."</a></h2>\n";

  echo '<div class="actions">';
  if (!$user->restricted) {
    // Delete
    echo '<a href="prefs.php?deleteCat=y"><img src="img/x.gif" alt="delete category" title="delete a category" /></a> ';

    // Edit
    echo '<a href="add.php?editCat='. $cat->id .'"><img src="img/edit.gif" alt="edit category" title="edit category" /></a> &nbsp;&nbsp;';
 
    // Add
    echo '<a href="add.php'. argsToUrl(array('new'=>'y','category'=>$cat->id)) .'"><img src="img/add.gif" alt="add feed" title="add a feed" /></a> ';
  }

  // Mark
  $args['seen'] = 'cat';
  $args['category'] = $cat->id;
  echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($args) .'">';
  echo '<img src="img/markall.gif" alt="mark category" title="mark category as read" /></a>';
  echo "</div></div>\n";
}

// -------------------------------------------------------------------------------
// Output feed header
// -------------------------------------------------------------------------------
function outputFeedhead(&$user, &$feed, $getArgs)
{
  echo '<div class="feedhead clearfix">' . "\n" .
    '<div class="feedtitle">' .
    '<a href="' . $feed->main_link . '" target="_blank">';

  if ($user->show_images) {
    $image = empty($feed->image_link) ? 'img/xml.png' : $feed->image_link;
    echo '<img src="' . $image . '" alt="' . htmlspecialchars($feed->name) . '" title="' . htmlspecialchars($feed->name) . '" />';
  }
  echo htmlspecialchars($feed->name) . '</a></div>';
  echo '<div class="actions">';

  if (!$user->restricted) {
    // Delete
    echo '<a href="prefs.php?delete_feed=' . $feed->id . '"><img src="img/x.gif" alt="delete" title="delete feed" /></a> ';

    // Edit
    echo '<a href="add.php?edit=' . $feed->id . '"><img src="img/edit.gif" alt="edit" title="edit feed" /></a> ';

    // Force update
    $updArgs = $getArgs;
    $updArgs['update'] = $feed->id;
    unset($updArgs['seen']);
    echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($updArgs) .'" title="force update of feed">';
    echo '<img src="img/update.gif" alt="update" title="force update of feed" /></a> &nbsp;&nbsp;';
  }

  // Mark
  $getArgs['seen'] = $feed->id;
  echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($getArgs);
  echo '" onclick="markfeed(\'feed'.$feed->id.'\');return false;" title="mark feed as read">';
  echo '<img src="img/mark.gif" alt="mark" title="mark feed as read" /></a>';

  echo '</div>';
  echo "</div>\n "; // feedhead
}

//----------------------------------------------------------------------------
function outputOneFeed (&$db, &$user, &$feed, $getArgs)
{
  echo "<div id=\"wrapper\"><div id=\"content\">\n";
  echo checkInsecureFilePerms();
  echo '<div class="feedwide">';
  outputFeedhead ($user, $feed, $getArgs);

  echo '<div id="feed'. $feed->id .'" class="feedcontent clearfix"><dl>';

  // Update the RSS links, if it's time.
  readRssFeed ($db, $user, $feed);

  $filter = 'WHERE src_id=\''. $user->userid . $feed->id .'\' ORDER BY id DESC';
  if ($user->max_links > 0)
    $filter .= ' LIMIT '. $user->max_links;

  foreach (feedlink::all($db, $filter) as $link) {
    echo '<dt><a href="redirect.php?redirect_link=' . urlencode($link->link) . '&amp;id=' . $feed->id . '&amp;artid=' . $link->id . '" class="' . $link->state . '">' . $link->title . "</a></dt>\n";
    echo '<dd>'. $link->description ."</dd>\n"; // XXX XSS opportunity
  }

  echo '</dl></div>';
  echo "</div></div></div>\n"; // feed, container, wrapper

  mysql_free_result($result);
}

//----------------------------------------------------------------------------
function outputFeeds (&$db, &$user, &$category, $getArgs)
{
  /*
   * make a table for each source in userid_feeds matching the specified category
   */
  echo "<div id=\"wrapper\"><div id=\"content\">\n";
  echo checkInsecureFilePerms();

  $cat = NULL;
  $firstCat = 1;
  $numInPair = 0;       // detect feedpairs

  $feeds = feed::all($db, $user->userid,
    (($category ? " WHERE cat_id='$category->id'" : '') ." ORDER BY cat_id, name"));

  if (count($feeds) > 0) {

    // Give some feedback to the user
    @ob_flush(); @flush();

    foreach ($feeds as $feed) {

      // Detect change of category, output new div to contain it
      if (!$cat || $feed->cat_id != $cat->id) {
        $cat = new category ($db, $feed->cat_id, $user->userid);
        if (!$cat->valid)
          $cat = new category();

        // Finish off the feedpair if it hasn't been closed yet
        if ($numInPair == 1) { echo "</div><!--FP0-->\n"; }
        $numInPair = 0;
        if (!$firstCat) { echo '</div><!--CAT-->'; } //category
        $firstCat = 0;

        outputCatHead ($user, $cat, $getArgs);
      }

      // We put each pair of feeds into a div to make the presentation nicer
      if ($numInPair == 0)
        echo '<div class="feedpair clearfix">';

      echo '<div class="feed">' . "\n";

      // start the individual feed
      outputFeedhead ($user, $feed, $getArgs);

      // Update the RSS links, if it's time.
      readRssFeed ($db, $user, $feed);

      $filter = "WHERE src_id='". $user->userid . $feed->id ."' AND state='new' ORDER BY id DESC LIMIT ". ($feed->headlines + 1);
      $links = feedlink::all ($db, $filter);

      echo '<div id="feed'.$feed->id.'" class="feedcontent clearfix"><dl>';

      $moreclass = 'seen';
      $n = 0;
      if (count($links) > 0) {

        while ($n < $feed->headlines && $n < count($links)) {
          $link =& $links[$n];
          echo '<dt id="'. $link->id .'" class="feedlink">'. feedlinkHTML ($feed->id, $link). "</dt>\n";
          $n++;
        }

        // Peek ahead at the next link (if one) to see its state
        if ($n == $feed->headlines && $n < count($links)) {
          $link =& $links[$n];
          $moreclass = ($link->state === 'new') ? 'new' : 'seen';
        }

      } else {
        echo '<dt id="none'. $feed->id. '" class="seen">&mdash; No new articles available.</dt>';
      }

      echo '<dt id="more'. $feed->id .'" class="more">';
      echo morelinkHTML($feed->id, $n, $moreclass) .'</dt></dl>';

      echo '<p class="all"><a href="' . $_SERVER['PHP_SELF'] . '?more=' . $feed->id . '" title="see all articles in this feed" class="seen">see all ...</a></p>';
      echo '<p class="info"><i>Updated '.date('F j, g:i a',strtotime($feed->last_update)).'</i></p>';

      echo "</div><!--FC-->\n</div><!--FD-->\n"; //feedcontent,feed
      $numInPair++;

      if ($numInPair == 2) {
        echo "</div><!--FP1-->\n";
        $numInPair = 0;
      } //feedpair

      // Give the user something to look at when RSS feeds are slowly updating
      @ob_flush(); @flush();

    } //foreach

    if ($numInPair == 1)
      echo "</div><!--FP2-->\n"; //feedpair

    echo '</div><!--CAT-->'; //category
  } else {
    echo '<div class="category"><p><a href="add.php?new=y'. ($category ? "&amp;category=$category->id" : '') .'">Add a feed</a> to get started!</p></div>';
  }

  echo '</div></div>'; //content,wrapper
}

function redirectToLogin() {
  header('Location: '. otherUrl('auth.php', TRUE));
  outputHeader();
  echo '<div id="wrapper"><div id="content"><div class="category">';
  echo '<p>You do not seem to be logged in! <a href="auth.php">Log in</a>.</p>';
  echo '</div></div></div>';
}

==> rnews-0.81.tar.gz: rnews-0.81/inc/output.php <==
<?php

require_once('rss.php');

// -------------------------------------------------------------------------------
function outputHeader ($user = NULL, $t = NULL, $status = NULL, $onload = NULL, $meta = NULL) {

  $title = RNEWS_TITLE;
  if (!empty($t)) { $title .= ": $t"; }

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<?php if ($meta) echo $meta ?>
    <link rel="stylesheet" href="rnews-side.css" type="text/css" />
    <script type="text/javascript" src="ajax.js"></script>
    <title><?php echo 'Rnews '.$title ?></title>
  </head>
  <body<?php if ($onload) echo " onload=\"$onload\"" ?>>
  <div id="container">
  <div id="header">
<?php
  echo '<h1><a href="index.php'.
    ($user != NULL ? "?category={$user->default_cat}" : '') .'">'. RNEWS_TITLE .'</a></h1>';
?>
    <?php outputUserActions($user) ?>
    <div id="status"><?php echo $status ? $status : '&nbsp;' ?></div>
  </div>
<?php

}

// -------------------------------------------------------------------------------
function outputUserActions(&$user) {
  echo '<div class="actions">';
  if ($user !== NULL && !$user->restricted) {
    echo htmlspecialchars($user->name) .': ';
    echo '<a href="prefs.php">Preferences</a>&nbsp;|&nbsp; ';
    echo '<a href="auth.php?logout=1">Log Out</a>';
  } else {
    echo '<a href="auth.php">Log In</a>';
  }
  echo '</div>';
}

// -------------------------------------------------------------------------------
// This provides category links in the header
//
function outputNavigation (&$db, &$user, $selCatId = 0) {

  echo '<div id="navigation"><ul>';
  echo '<li><a href="index.php"><em>All Sources</em></a></li>';

	foreach (category::all($db, $user->userid, 'ORDER BY name') as $cat) {
		echo '<li'. (($selCatId && ($selCatId == $cat->id)) ? ' class="selected"' : '')
			.'><a href="index.php?category='. $cat->id .'">'. htmlspecialchars($cat->name) .'</a></li>';
	}

  echo '</ul></div>' . "\n";
}

// -------------------------------------------------------------------------------
function outputCatHead (&$user, &$cat, $args) {
  echo "\n<div class=\"category\">\n";
  echo '<div class="categoryHead clearfix">';
  echo '<h2><a href="' . $_SERVER['PHP_SELF'] . "?category=$cat->id\">". htmlspecialchars($cat->name) ."</a></h2>\n";

  echo '<div class="actions">';

  // view type
  $a2 = $args;
  $a2['category'] = $cat->id;
  $a2['view'] = (isset($user->prefs['V']) && $user->prefs['V']=='L') ? 'B' : 'L';
  echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($a2) .'">'.
    ((isset($user->prefs['V']) && $user->prefs['V']=='B') ? '(go to list view)' : '(go to block view)') .'</a>&nbsp; ';

  if (!$user->restricted) {
    // Delete
    echo '<a href="prefs.php?deleteCat=y"><img src="img/x.gif" alt="delete category" title="delete a category" /></a> ';

    // Edit
    echo '<a href="add.php?editCat='. $cat->id .'"><img src="img/edit.gif" alt="edit category" title="edit category" /></a> &nbsp;&nbsp;';
 
    // Add
    echo '<a href="add.php'. argsToUrl(array('new'=>'y','category'=>$cat->id)) .'"><img src="img/add.gif" alt="add feed" title="add a feed" /></a> ';
  }

  // Mark
  $args['seen'] = 'cat';
  $args['category'] = $cat->id;
  echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($args) .'">';
  echo '<img src="img/markall.gif" alt="mark category" title="mark category as read" /></a>';
  echo "</div></div>\n";
}

// -------------------------------------------------------------------------------
// Output feed header
// -------------------------------------------------------------------------------
function outputFeedhead(&$user, &$feed, $getArgs)
{
  echo '<div class="feedhead clearfix">' . "\n" .
    '<div class="feedtitle">' .
    '<a href="' . $feed->main_link . '" target="_blank">';

  if ($user->show_images) {
    $image = empty($feed->image_link) ? 'img/xml.png' : $feed->image_link;
    echo '<img src="' . $image . '" alt="' . htmlspecialchars($feed->name) . '" title="' . htmlspecialchars($feed->name) . '" />';
  }
  echo htmlspecialchars($feed->name) . '</a></div>';
  echo '<div class="actions">';

  if (!$user->restricted) {
    // Delete
    echo '<a href="prefs.php?delete_feed=' . $feed->id . '"><img src="img/x.gif" alt="delete" title="delete feed" /></a> ';

    // Edit
    echo '<a href="add.php?edit=' . $feed->id . '"><img src="img/edit.gif" alt="edit" title="edit feed" /></a> ';

    // Force update
    $updArgs = $getArgs;
    $updArgs['update'] = $feed->id;
    unset($updArgs['seen']);
    echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($updArgs) .'" title="force update of feed">';
    echo '<img src="img/update.gif" alt="update" title="force update of feed" /></a> &nbsp;&nbsp;';
  }

  // Mark
  $getArgs['seen'] = $feed->id;
  echo '<a href="'. $_SERVER['PHP_SELF'] . argsToUrl($getArgs);
  echo '" onclick="markfeed(\'feed'.$feed->id.'\');return false;" title="mark feed as read">';
  echo '<img src="img/mark.gif" alt="mark" title="mark feed as read" /></a>';

  echo '</div>';
  echo "</div>\n "; // feedhead
}

//----------------------------------------------------------------------------
function outputOneFeed (&$db, &$user, &$feed, $getArgs)
{
  echo "<div id=\"wrapper\"><div id=\"content\">\n";
  echo checkInsecureFilePerms();
  echo '<div class="feedwide">';
  outputFeedhead ($user, $feed, $getArgs);

  echo '<div id="feed'. $feed->id .'" class="feedcontent clearfix"><dl>';

  // Update the RSS links, if it's time.
  readRssFeed ($db, $user, $feed);

  $filter = 'WHERE src_id=\''. $user->userid . $feed->id .'\' ORDER BY id DESC';
  if ($user->max_links > 0)
    $filter .= ' LIMIT '. $user->max_links;

  foreach (feedlink::all($db, $filter) as $link) {
    echo '<dt><a href="redirect.php?redirect_link=' . urlencode($link->link) . '&amp;id=' . $feed->id . '&amp;artid=' . $link->id . '" class="' . $link->state . '">' . $link->title . "</a></dt>\n";
    echo '<dd>'. $link->description ."</dd>\n"; // XXX XSS opportunity
  }

  echo '</dl></div>';
  echo "</div></div></div>\n"; // feed, container, wrapper

  mysql_free_result($result);
}

//----------------------------------------------------------------------------
// This is somewhat complicated because it handles:
//  - printing all or a single category
//  - printing block and list views
//
function outputFeeds (&$db, &$user, &$category, $getArgs)
{
  $nunread = 0;
  $blockView = !isset($user->prefs['V']) || $user->prefs['V'] == 'B';

  echo "<div id=\"wrapper\"><div id=\"content\">\n";
  echo checkInsecureFilePerms();

  $cat = NULL;
  $numInPair = 0;       // detect feedpairs

  $feeds = feed::all($db, $user->userid,
    (($category ? " WHERE cat_id='$category->id'" : '') ." ORDER BY cat_id, name"));

  if (count($feeds) > 0) {

    // Give some feedback to the user
    @ob_flush(); @flush();

    foreach ($feeds as $feed) {

      // Detect change of category, output new div to contain it
      if (!$cat || $feed->cat_id != $cat->id) {
        $firstCat = ($cat == NULL);
        $cat = new category ($db, $feed->cat_id, $user->userid);
        if (!$cat->valid)
          $cat = new category();

        if ($blockView) {
          // Finish off the feedpair if it hasn't been closed yet
          if ($numInPair == 1) { echo "</div>\n"; }
          $numInPair = 0;
        }
        if (!$firstCat) {
          if (!$blockView)
            echo '</dl></div></div></div>'; //dl,feedcontent,feedwide,div
          echo '</div>'; //category
        }

        outputCatHead ($user, $cat, $getArgs);

        if (!$blockView) {
          echo '<div class="clearfix">';
          echo '<div class="feedwide">';
          echo '<div class="feedcontent clearfix">';
          echo '<dl>';
        }
      }

      if ($blockView) {
        // We put each pair of feeds into a div to make the presentation nicer
        if ($numInPair == 0)
          echo '<div class="feedpair clearfix">';
        echo '<div class="feed">';
      }

      // start the individual feed
      if ($blockView)
        outputFeedhead ($user, $feed, $getArgs);

      // Update the RSS links, if it's time.
      readRssFeed ($db, $user, $feed);

      $filter = "WHERE src_id='". $user->userid . $feed->id ."' AND state='new' ORDER BY id DESC LIMIT ". ($feed->headlines + 1);
      $links = feedlink::all ($db, $filter);
      $nunread += count($links);

      if ($blockView)
        echo '<div id="feed'.$feed->id.'" class="feedcontent clearfix"><dl>';

      $moreclass = 'seen';
      $n = 0;
      if (count($links) > 0) {

        while ($n < $feed->headlines && $n < count($links)) {
          $link =& $links[$n];
          echo '<dt id="'. $link->id .'" class="feedlink">'.
            feedlinkHTML ($feed->id, $link, ($blockView ? NULL : $feed->name)). "</dt>\n";
          $n++;
        }

        // Peek ahead at the next link (if one) to see its state
        if ($n == $feed->headlines && $n < count($links)) {
          $link =& $links[$n];
          $moreclass = ($link->state === 'new') ? 'new' : 'seen';
        }

      } else {
        if ($blockView)
          echo '<dt id="none'. $feed->id. '" class="seen">&mdash; No new articles available.</dt>';
      }

      if ($blockView) {
        echo '<dt id="more'. $feed->id .'" class="more">';
        echo morelinkHTML($feed->id, $n, $moreclass) .'</dt></dl>';

        echo '<p class="all"><a href="' . $_SERVER['PHP_SELF'] . '?more=' . $feed->id . '" title="see all articles in this feed" class="seen">see all ...</a></p>';
        echo '<p class="info"><i>Updated '.date('F j, g:i a',strtotime($feed->last_update)).'</i></p>';

        echo "</div>\n</div>\n"; //feedcontent,feed
        $numInPair++;

        if ($numInPair == 2) {
          echo "</div>\n";
          $numInPair = 0;
        } //feedpair
      }

      // Give the user something to look at when RSS feeds are slowly updating
      @ob_flush(); @flush();

    } //foreach feed

    if ($blockView) {
      if ($numInPair == 1)
        echo "</div>\n"; //feedpair
    } else {
      if ($nunread == 0) {
        echo '<dt id="none'. $feed->id. '" class="seen">&mdash; No new articles available.</dt>';
      }
      echo '</dl></div></div></div>'; //dl,feedcontent,feedwide,div
    }

    echo '</div>'; //category
  } else {
    echo '<div class="category"><p><a href="add.php?new=y'. ($category ? "&amp;category=$category->id" : '') .'">Add a feed</a> to get started!</p></div>';
  }

  echo '</div></div>'; //content,wrapper
}

function redirectToLogin() {
  header('Location: '. otherUrl('auth.php', FORCE_SLOGIN));
  outputHeader();
  echo '<div id="wrapper"><div id="content"><div class="category">';
  echo '<p>You do not seem to be logged in! <a href="auth.php">Log in</a>.</p>';
  echo '</div></div></div>';
}
